@@ -19,13 +19,14 @@ createconfigparser.add_argument(
 
 buildparser.add_argument(
     "version",
-    default="micro",
-    const="micro",
+    default="keep",
+    const="keep",
     nargs="?",
-    choices=["micro", "minor", "major"],
+    choices=["keep", "micro", "minor", "major"],
     help="image patch build version",
 )
 buildparser.add_argument("push", type=str, nargs="?", help="to push docker images")
+buildparser.add_argument("-r", "--registry", help="Config custom registry URL")
 buildparser.add_argument(
     "-f", "--filename", help="Config custom file name", default="docker.ini"
 )
